==> newland-page-frame-provider-2.0.0-92b515.zip: CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.0] - 2019-04-02
### Added
- PageFrameProvider routes can now declare `BreadcrumbProviders` for custom breadcrumbs.
- New base fusion object can now be specified using `pageFrame.default.type = 'Your.Site:CustomSubPage'`
  without having to override the whole fusion object.
- Every template rendered in a PageFrame now can access a `isPageFrame` variable for building conditions.
- `PageFrameContextService` can now be injected in order to access details about the current page frame route. This can be useful if code external to this package needs to access the current node or dimension values.
- `RouteConfigurationHelper` can be used for implementing custom route parts based on page frames using a clearly defined configuration format. This helper resolves paths & dimensions.

### Breaking Changes
- `Newland.PageFrameProvider:PageFrame` is now not a page object itself but a renderer that renders
  a page object. This means that customizations to page frames now have to be done to 
  `prototype(Newland.PageFrameProvider:PageFrame).prototype(Neos.NodeTypes:Page)` instead of
  `prototype(Newland.PageFrameProvider:PageFrame)`.

```neosfusion
# A custom wrap
pageFrame.poiDetail = Newland.PageFrameProvider:PageFrame {
    body.content.main.@process.wrapWithContainer = ${'<div class="o-container mt-8">' + value + '</div>'}
}

# Must be applied to the sub-prototype
pageFrame.poiDetail = Newland.PageFrameProvider:PageFrame {
    prototype(Neos.NodeTypes:Page) {
        body.content.main.@process.wrapWithContainer = ${'<div class="o-container mt-8">' + value + '</div>'}
    }
}
```

==> newland-page-frame-provider-2.0.2-8084ab.zip: CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.2] - 2019-05-07
### Fixed
- BreadcrumbMenu is now compatible with Neos 4.3
- Fixed issues with upcoming `Newland.RoutingBehaviourHooks` package

### Breaking Changes
- `BreadcrumbProvider` interface has been moved to `Newland\PageFrameProvider\Breadcrumb\`.
  The interface was only moved, the definition remains the same.

## [2.0.1] - 2019-04-03
### Fixed
- Fixed breaking URLs without language segments.

## [2.0.0] - 2019-04-02
### Added
- PageFrameProvider routes can now declare `BreadcrumbProviders` for custom breadcrumbs.
- New base fusion object can now be specified using `pageFrame.default.type = 'Your.Site:CustomSubPage'`
  without having to override the whole fusion object.
- Every template rendered in a PageFrame now can access a `isPageFrame` variable for building conditions.
- `PageFrameContextService` can now be injected in order to access details about the current page frame route. This can be useful if code external to this package needs to access the current node or dimension values.
- `RouteConfigurationHelper` can be used for implementing custom route parts based on page frames using a clearly defined configuration format. This helper resolves paths & dimensions.

### Breaking Changes
- `Newland.PageFrameProvider:PageFrame` is now not a page object itself but a renderer that renders
  a page object. This means that customizations to page frames now have to be done to 
  `prototype(Newland.PageFrameProvider:PageFrame).prototype(Neos.NodeTypes:Page)` instead of
  `prototype(Newland.PageFrameProvider:PageFrame)`.

```neosfusion
# A custom wrap
pageFrame.poiDetail = Newland.PageFrameProvider:PageFrame {
    body.content.main.@process.wrapWithContainer = ${'<div class="o-container mt-8">' + value + '</div>'}
}

# Must be applied to the sub-prototype
pageFrame.poiDetail = Newland.PageFrameProvider:PageFrame {
    prototype(Neos.NodeTypes:Page) {
        body.content.main.@process.wrapWithContainer = ${'<div class="o-container mt-8">' + value + '</div>'}
    }
}
```
